//$Id: string-res.cc,v 1.18 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "string-res.h"
#include "string-win.h"

using namespace Guikachu;

Resources::String::String (ResourceManager   *manager,
			   const std::string &id):
    Resource (manager, id),
    gui (0),
    text (changed, "")
{
}

Resources::String::~String ()
{
    delete gui;
}

void Resources::String::show_ui ()
{
    if (!gui)
	gui = new GUI::StringWindow (this);

    gui->show ();
}
